More lint cleanups and breakage fixes.

The previous CL was a premature submit due to lack of coffee.

Change-Id: Id425d0ef332f569a954f0413e6b1ae6087f40f30
diff --git a/internal/ceres/lapack.h b/internal/ceres/lapack.h
index 53a33e1..8933c2c 100644
--- a/internal/ceres/lapack.h
+++ b/internal/ceres/lapack.h
@@ -51,14 +51,14 @@
   //
   // This function uses the LAPACK dpotrf and dpotrs routines.
   //
   // The return value and the status string together describe whether
   // the solver terminated successfully or not and if so, what was the
   // reason for failure.
   static LinearSolverTerminationType SolveInPlaceUsingCholesky(
       int num_rows,
       const double* lhs,
       double* rhs_and_solution,
-      string* status);
+      string* message);
 
   // The SolveUsingQR function requires a buffer for its temporary
   // computation. This function given the size of the lhs matrix will
@@ -81,7 +81,7 @@
   //
   // This function uses the LAPACK dgels routine.
   //
   // The return value and the status string together describe whether
   // the solver terminated successfully or not and if so, what was the
   // reason for failure.
   static LinearSolverTerminationType SolveInPlaceUsingQR(
@@ -91,7 +91,7 @@
       int work_size,
       double* work,
       double* rhs_and_solution,
-      string* status);
+      string* message);
 };
 
 }  // namespace internal
@@ -51,14 +51,14 @@
   // This function uses the LAPACK dpotrf and dpotrs routines.
   //
-  // The return value and the status string together describe whether
+  // The return value and the message string together describe whether
   // the solver terminated successfully or not and if so, what was the
   // reason for failure.
@@ -81,7 +81,7 @@
   // This function uses the LAPACK dgels routine.
   //
-  // The return value and the status string together describe whether
+  // The return value and the message string together describe whether
   // the solver terminated successfully or not and if so, what was the
   // reason for failure.